==> packageinstaller-pkglist-libre_0.1.7.tar.xz: packageinstaller-pkglist-libre/Vietnamese_Default_Firefox_esr.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Vietnamese_Default_Firefox_esr
</name>

<description>
   <am>Vietnamese localisation Firefox ESR</am>
   <ar>Vietnamese localisation Firefox ESR</ar>
   <be>Vietnamese localisation Firefox ESR</be>
   <bg>Vietnamese localisation Firefox ESR</bg>
   <bn>Vietnamese localisation Firefox ESR</bn>
   <ca>Vietnamese localisation Firefox ESR</ca>
   <cs>Vietnamese localisation Firefox ESR</cs>
   <da>Vietnamese localisation Firefox ESR</da>
   <de>Vietnamesische Lokalisation von “Firefox ESR”</de>
   <el>Βιετναμέζικα για Firefox ESR</el>
   <en>Vietnamese localisation Firefox ESR</en>
   <es_ES>Vietnamese localisation Firefox ESR</es_ES>
   <es>Localización Vietnamita de Firefox ESR</es>
   <et>Vietnamese localisation Firefox ESR</et>
   <eu>Vietnamese localisation Firefox ESR</eu>
   <fa>Vietnamese localisation Firefox ESR</fa>
   <fil_PH>Vietnamese localisation Firefox ESR</fil_PH>
   <fi>Vietnamese localisation Firefox ESR</fi>
   <fr_BE>Localisation en vietnamien pour Firefox ESR</fr_BE>
   <fr>Localisation en vietnamien pour Firefox ESR</fr>
   <gl_ES>Vietnamese localisation Firefox ESR</gl_ES>
   <he_IL>Vietnamese localisation Firefox ESR</he_IL>
   <hi>Vietnamese localisation Firefox ESR</hi>
   <hr>Vietnamese localisation Firefox ESR</hr>
   <hu>Vietnamese localisation Firefox ESR</hu>
   <id>Vietnamese localisation Firefox ESR</id>
   <is>Vietnamese localisation Firefox ESR</is>
   <it>Vietnamese localisation Firefox ESR</it>
   <ja>ベトナム語版 Firefox ESR</ja>
   <kk>Vietnamese localisation Firefox ESR</kk>
   <ko>Vietnamese localisation Firefox ESR</ko>
   <lt>Vietnamese localisation Firefox ESR</lt>
   <mk>Vietnamese localisation Firefox ESR</mk>
   <mr>Vietnamese localisation Firefox ESR</mr>
   <nb_NO>Vietnamese localisation Firefox ESR</nb_NO>
   <nb>Vietnamesisk lokaltilpassing av Firefox ESR</nb>
   <nl_BE>Vietnamese localisation Firefox ESR</nl_BE>
   <nl>Vietnamese localisation Firefox ESR</nl>
   <pl>Vietnamese localisation Firefox ESR</pl>
   <pt_BR>Vietnamita Localização para o Firefox ESR</pt_BR>
   <pt>Vietnamese localisation Firefox ESR</pt>
   <ro>Vietnamese localisation Firefox ESR</ro>
   <ru>Vietnamese localisation Firefox ESR</ru>
   <sk>Vietnamese localisation Firefox ESR</sk>
   <sl>Vietnamese localisation Firefox ESR</sl>
   <sq>Vietnamese localisation Firefox ESR</sq>
   <sr>Vietnamese localisation Firefox ESR</sr>
   <sv>Vietnamesisk lokalisering av Firefox ESR</sv>
   <th>Vietnamese localisation Firefox ESR</th>
   <tr>Vietnamese localisation Firefox ESR</tr>
   <uk>Vietnamese localisation Firefox ESR</uk>
   <vi>Vietnamese localisation Firefox ESR</vi>
   <zh_CN>Vietnamese localisation Firefox ESR</zh_CN>
   <zh_HK>Vietnamese localisation Firefox ESR</zh_HK>
   <zh_TW>Vietnamese localisation Firefox ESR</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
firefox-esr-l10n-vi
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
firefox-esr-l10n-vi
</uninstall_package_names>

</app>

==> packageinstaller-pkglist-libre_0.1.8.tar.xz: packageinstaller-pkglist-libre/Vietnamese_Default_Firefox_esr.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Vietnamese_Default_Firefox_esr
</name>

<description>
   <am>Vietnamese localisation Firefox ESR</am>
   <ar>Vietnamese localisation Firefox ESR</ar>
   <be>Vietnamese localisation Firefox ESR</be>
   <bg>Vietnamese localisation Firefox ESR</bg>
   <bn>Vietnamese localisation Firefox ESR</bn>
   <ca>Vietnamese localisation Firefox ESR</ca>
   <cs>Vietnamese localisation Firefox ESR</cs>
   <da>Vietnamese localisation Firefox ESR</da>
   <de>Vietnamesische Lokalisation von “Firefox ESR”</de>
   <el>Βιετναμέζικα για Firefox ESR</el>
   <en>Vietnamese localisation Firefox ESR</en>
   <es_ES>Localización Vietnamita de Firefox ESR</es_ES>
   <es>Localización Vietnamita de Firefox ESR</es>
   <et>Vietnamese localisation Firefox ESR</et>
   <eu>Vietnamese localisation Firefox ESR</eu>
   <fa>Vietnamese localisation Firefox ESR</fa>
   <fil_PH>Vietnamese localisation Firefox ESR</fil_PH>
   <fi>Vietnamese localisation Firefox ESR</fi>
   <fr_BE>Vietnamese localisation Firefox ESR</fr_BE>
   <fr>Localisation en vietnamien pour Firefox ESR</fr>
   <gl_ES>Vietnamese localisation Firefox ESR</gl_ES>
   <gu>Vietnamese localisation Firefox ESR</gu>
   <he_IL>Vietnamese localisation Firefox ESR</he_IL>
   <hi>Vietnamese localisation Firefox ESR</hi>
   <hr>Vietnamese localisation Firefox ESR</hr>
   <hu>Vietnamese localisation Firefox ESR</hu>
   <id>Vietnamese localisation Firefox ESR</id>
   <is>Vietnamese localisation Firefox ESR</is>
   <it>Localizzazione vietnamita di Firefox ESR</it>
   <ja>ベトナム語版 Firefox ESR</ja>
   <kk>Vietnamese localisation Firefox ESR</kk>
   <ko>Vietnamese localisation Firefox ESR</ko>
   <lt>Vietnamese localisation Firefox ESR</lt>
   <mk>Vietnamese localisation Firefox ESR</mk>
   <mr>Vietnamese localisation Firefox ESR</mr>
   <nb_NO>Vietnamese localisation Firefox ESR</nb_NO>
   <nb>Vietnamesisk lokaltilpassing av Firefox ESR</nb>
   <nl_BE>Vietnamese localisation Firefox ESR</nl_BE>
   <nl>Vietnamese localisation Firefox ESR</nl>
   <pl>Vietnamese localisation Firefox ESR</pl>
   <pt_BR>Vietnamita Localização para o Firefox ESR</pt_BR>
   <pt>Vietnamese localisation Firefox ESR</pt>
   <ro>Vietnamese localisation Firefox ESR</ro>
   <ru>Vietnamese localisation Firefox ESR</ru>
   <sk>Vietnamese localisation Firefox ESR</sk>
   <sl>Vietnamese localisation Firefox ESR</sl>
   <sq>Vietnamese localisation Firefox ESR</sq>
   <sr>Vietnamese localisation Firefox ESR</sr>
   <sv>Vietnamesisk lokalisering av Firefox ESR</sv>
   <th>Vietnamese localisation Firefox ESR</th>
   <tr>Vietnamese localisation Firefox ESR</tr>
   <uk>Vietnamese localisation Firefox ESR</uk>
   <vi>Vietnamese localisation Firefox ESR</vi>
   <zh_CN>Vietnamese localisation Firefox ESR</zh_CN>
   <zh_HK>Vietnamese localisation Firefox ESR</zh_HK>
   <zh_TW>Vietnamese localisation Firefox ESR</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
firefox-esr-l10n-vi
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
firefox-esr-l10n-vi
</uninstall_package_names>

</app>
